public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [Patch] scsi:megaraid_sas:Update module author
@ 2006-12-29 16:13 Sumant Patro
  0 siblings, 0 replies; only message in thread
From: Sumant Patro @ 2006-12-29 16:13 UTC (permalink / raw)
  To: James.Bottomley, akpm; +Cc: linux-scsi, linux-kernel, neela.kolli, bo.yang

[-- Attachment #1: Type: text/plain, Size: 976 bytes --]

Update domain name change from lsil.com to lsi.com.
Change module author to megaraidlinux@lsi.com

Signed-Off By: Sumant Patro <sumant.patro@lsi.com>

diff -uprN linux-2.6.orig/drivers/scsi/megaraid/megaraid_sas.c linux-2.6.new/drivers/scsi/megaraid/megaraid_sas.c
--- linux-2.6.orig/drivers/scsi/megaraid/megaraid_sas.c 2006-12-28 09:56:05.000000000 -0800
+++ linux-2.6.new/drivers/scsi/megaraid/megaraid_sas.c 2006-12-29 07:17:21.000000000 -0800
@@ -13,8 +13,8 @@
  * Version : v00.00.03.05
  *
  * Authors:
  *  Sreenivas Bagalkote <Sreenivas.Bagalkote@lsil.com>
  *  Sumant Patro  <Sumant.Patro@lsil.com>
  *
  * List of supported controllers
  *
@@ -45,7 +45,7 @@
 
 MODULE_LICENSE("GPL");
 MODULE_VERSION(MEGASAS_VERSION);
-MODULE_AUTHOR("sreenivas.bagalkote@lsil.com");
+MODULE_AUTHOR("megaraidlinux@lsi.com");
 MODULE_DESCRIPTION("LSI Logic MegaRAID SAS Driver");
 
 /*
@@ -13,8 +13,8 @@
  *
  * Authors:
- *  Sreenivas Bagalkote <Sreenivas.Bagalkote@lsil.com>
- *  Sumant Patro  <Sumant.Patro@lsil.com>
+ *  Sreenivas Bagalkote <Sreenivas.Bagalkote@lsi.com>
+ *  Sumant Patro  <Sumant.Patro@lsi.com>
  *
  * List of supported controllers


[-- Attachment #2: megaraid_sas_update_author.patch --]
[-- Type: text/x-patch, Size: 824 bytes --]

diff -uprN linux-2.6.orig/drivers/scsi/megaraid/megaraid_sas.c linux-2.6.new/drivers/scsi/megaraid/megaraid_sas.c
--- linux-2.6.orig/drivers/scsi/megaraid/megaraid_sas.c	2006-12-28 09:56:05.000000000 -0800
+++ linux-2.6.new/drivers/scsi/megaraid/megaraid_sas.c	2006-12-29 07:17:21.000000000 -0800
@@ -13,8 +13,8 @@
  * Version	: v00.00.03.05
  *
  * Authors:
  * 	Sreenivas Bagalkote	<Sreenivas.Bagalkote@lsil.com>
  * 	Sumant Patro		<Sumant.Patro@lsil.com>
  *
  * List of supported controllers
  *
@@ -45,7 +45,7 @@
 
 MODULE_LICENSE("GPL");
 MODULE_VERSION(MEGASAS_VERSION);
-MODULE_AUTHOR("sreenivas.bagalkote@lsil.com");
+MODULE_AUTHOR("megaraidlinux@lsi.com");
 MODULE_DESCRIPTION("LSI Logic MegaRAID SAS Driver");
 
 /*

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2006-12-29 21:24 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -13,8 +13,8 @@
  *
  * Authors:
- * 	Sreenivas Bagalkote	<Sreenivas.Bagalkote@lsil.com>
- * 	Sumant Patro		<Sumant.Patro@lsil.com>
+ * 	Sreenivas Bagalkote	<Sreenivas.Bagalkote@lsi.com>
+ * 	Sumant Patro		<Sumant.Patro@lsi.com>
  *
  * List of supported controllers
2006-12-29 16:13 [Patch] scsi:megaraid_sas:Update module author Sumant Patro

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox